@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0053';
+our $VERSION = '0.0054';
 
 use Moo;
 use strictures 2;
@@ -413,7 +413,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0053
+version 0.0054
 
 =head1 SYNOPSIS
 
@@ -424,8 +424,8 @@ version 0.0053
 
   # populate the database with patch settings from a YAML file or string
   my $patches = $synth->import_yaml(
-      file    => "$model.yaml", # or string => ...
-      patches => ['Simple 001', 'Simple 002' ],
+      file    => "$model.yaml", # or string => '...' # one or the other is required
+      patches => ['Simple 001', 'Simple 002' ],      # optional
   );
 
   # populate the database with individual settings
@@ -482,7 +482,7 @@ version 0.0053
   # { order => [ ... ], etc => ... }
 
   # remove stuff!
-  $synth->remove_spec;
+  $synth->remove_spec;                     # remove the current model specification
   $synth->remove_setting(id => $id1);      # remove a particular setting
   $synth->remove_settings(name => $patch); # remove all settings sharing the same name
   $synth->remove_model(model => $model);   # remove the entire model
@@ -664,10 +664,10 @@ Visualize a patch of B<settings> with the L<GraphViz2> module.
 
 Option defaults:
 
+  model_name = undef (required)
+  settings   = undef (required)
   render     = 0
   path       = .
-  model_name = model
-  patch_name = patch
   extension  = png
   shape      = oval
   color      = grey
